List:Commits« Previous MessageNext Message »
From:mikael Date:May 15 2007 6:07pm
Subject:bk commit into 5.1 tree (mikron:1.2519)
View as plain text  
Below is the list of changes that have just been committed into a local
5.1 repository of mikron. When mikron does a push these changes will
be propagated to the main repository and, within 24 hours after the
push, to the public repository.
For information on how to access the public repository
see http://dev.mysql.com/doc/mysql/en/installing-source-tree.html

ChangeSet@stripped, 2007-05-15 20:07:05+02:00, mikron@stripped +5 -0
  Merge mikael@stripped:/home/mikael/mysql_clones/sched_rt
  into  mikael-ronstr-ms-dator.local:/Users/mikron/mysql_clones/sched_rt
  MERGE: 1.2516.1.1

  storage/ndb/include/portlib/NdbThread.h@stripped, 2007-05-15 20:07:00+02:00, mikron@stripped +0 -0
    Auto merged
    MERGE: 1.8.1.1

  storage/ndb/src/common/portlib/NdbThread.c@stripped, 2007-05-15 20:07:00+02:00, mikron@stripped +0 -0
    Auto merged
    MERGE: 1.34.1.1

  storage/ndb/src/common/transporter/TransporterRegistry.cpp@stripped, 2007-05-15 20:07:00+02:00, mikron@stripped +0 -0
    Auto merged
    MERGE: 1.72.1.1

  storage/ndb/src/common/util/SocketServer.cpp@stripped, 2007-05-15 20:07:00+02:00, mikron@stripped +0 -0
    Auto merged
    MERGE: 1.25.1.1

  storage/ndb/src/ndbapi/TransporterFacade.cpp@stripped, 2007-05-15 20:07:00+02:00, mikron@stripped +0 -0
    Auto merged
    MERGE: 1.65.1.2

# This is a BitKeeper patch.  What follows are the unified diffs for the
# set of deltas contained in the patch.  The rest of the patch, the part
# that BitKeeper cares about, is below these diffs.
# User:	mikron
# Host:	mikael-ronstr-ms-dator.local
# Root:	/Users/mikron/mysql_clones/sched_rt/RESYNC

--- 1.35/storage/ndb/src/common/portlib/NdbThread.c	2007-05-15 19:55:56 +02:00
+++ 1.36/storage/ndb/src/common/portlib/NdbThread.c	2007-05-15 20:07:00 +02:00
@@ -246,7 +246,7 @@
 }
 
 NDB_TID_TYPE
-Ndb_getThreadId()
+NdbThread_getThreadId()
 {
 #ifdef HAVE_LINUX_AFFINITY
   pid_t tid = gettid();
@@ -272,7 +272,7 @@
 }
 
 NDB_THAND_TYPE
-Ndb_getThreadHandle()
+NdbThread_getThreadHandle()
 {
 #ifdef HAVE_LINUX_SCHEDULING
   pid_t tid = gettid();
@@ -344,8 +344,8 @@
 }
 
 int
-Ndb_SetScheduler(NDB_THAND_TYPE threadHandle, bool rt_prio,
-                 bool high_prio)
+NdbThread_SetScheduler(NDB_THAND_TYPE threadHandle, bool rt_prio,
+                       bool high_prio)
 {
   int policy, prio, error_no= 0;
 #ifdef HAVE_LINUX_SCHEDULING
@@ -395,7 +395,7 @@
 }
 
 int
-Ndb_LockCPU(NDB_TID_TYPE threadId, Uint32 cpu_id)
+NdbThread_LockCPU(NDB_TID_TYPE threadId, Uint32 cpu_id)
 {
   int error_no= 0;
 #ifdef HAVE_LINUX_AFFINITY

--- 1.73/storage/ndb/src/common/transporter/TransporterRegistry.cpp	2007-05-15 19:55:56 +02:00
+++ 1.74/storage/ndb/src/common/transporter/TransporterRegistry.cpp	2007-05-15 20:07:00 +02:00
@@ -1168,16 +1168,16 @@
   uint len;
 
   m_run_start_clients_thread= true;
-  fill_thread_object((void*)thread_object, &len, FALSE);
+  ndb_thread_fill_thread_object((void*)thread_object, &len, FALSE);
   m_start_clients_thread= NdbThread_CreateWithFunc(run_start_clients_C,
 					   (void**)this,
 					   32768,
 					   "ndb_start_clients",
 					   NDB_THREAD_PRIO_LOW,
-                                           add_thread_id,
+                                           ndb_thread_add_thread_id,
                                            thread_object,
                                            len,
-                                           remove_thread_id,
+                                           ndb_thread_remove_thread_id,
                                            thread_object,
                                            len);
   if (m_start_clients_thread == 0) {

--- 1.26/storage/ndb/src/common/util/SocketServer.cpp	2007-05-15 19:55:56 +02:00
+++ 1.27/storage/ndb/src/common/util/SocketServer.cpp	2007-05-15 20:07:00 +02:00
@@ -219,16 +219,16 @@
 
   m_threadLock.lock();
   if(m_thread == 0 && m_stopThread == false){
-    fill_thread_object((void*)thread_object, &len, TRUE);
+    ndb_thread_fill_thread_object((void*)thread_object, &len, TRUE);
     m_thread = NdbThread_CreateWithFunc(socketServerThread_C,
 				(void**)this,
 				32768,
 				"NdbSockServ",
 				NDB_THREAD_PRIO_LOW,
-                                add_thread_id,
+                                ndb_thread_add_thread_id,
                                 thread_object,
                                 len,
-                                remove_thread_id,
+                                ndb_thread_remove_thread_id,
                                 thread_object,
                                 len);
   }

--- 1.67/storage/ndb/src/ndbapi/TransporterFacade.cpp	2007-05-15 16:24:43 +02:00
+++ 1.68/storage/ndb/src/ndbapi/TransporterFacade.cpp	2007-05-15 20:07:00 +02:00
@@ -60,17 +60,17 @@
  * Call back functions
  *****************************************************************************/
 
-void* add_thread_id(void *param)
+void* ndb_thread_add_thread_id(void *param)
 {
   return NULL;
 }
 
-void *remove_thread_id(void *param)
+void *ndb_thread_remove_thread_id(void *param)
 {
   return NULL;
 }
 
-void fill_thread_object(void *param, uint *len, bool server)
+void ndb_thread_fill_thread_object(void *param, uint *len, bool server)
 {
   *len = 0;
 }
Thread
bk commit into 5.1 tree (mikron:1.2519)mikael17 May
--- 1.9/storage/ndb/include/portlib/NdbThread.h	2007-05-15 19:55:56 +02:00
+++ 1.10/storage/ndb/include/portlib/NdbThread.h	2007-05-15 20:07:00 +02:00
@@ -60,20 +60,20 @@
  * threads and SocketServer threads. In the NDB kernel they are
  * used to set real-time properties and lock threads to CPU's. In
  * the NDB API they are dummy subroutines.
  * add_thread_id is used before starting run method in thread.
  * remove_thread_id is called immediately after returning from
  * run-method in thread.
  * fill_thread_object is called before calling add_thread_id to
  * prepare parameters.
  */
 void*
-add_thread_id(void *param);
+ndb_thread_add_thread_id(void *param);
 
 void*
-remove_thread_id(void *param);
+ndb_thread_remove_thread_id(void *param);
 
 void
-fill_thread_object(void *param, uint *len, bool server);
+ndb_thread_fill_thread_object(void *param, uint *len, bool server);
 
 struct NdbThread;
 
@@ -148,23 +148,23 @@
 /**
  * Get thread id
  */
-NDB_TID_TYPE Ndb_getThreadId();
+NDB_TID_TYPE NdbThread_getThreadId();
 
 /**
  * Get thread handle
  */
-NDB_THAND_TYPE Ndb_getThreadHandle();
+NDB_THAND_TYPE NdbThread_getThreadHandle();
 
 /**
  * Set Scheduler for pid
  */
-int Ndb_SetScheduler(NDB_THAND_TYPE threadHandle, bool rt_prio,
-                     bool high_prio);
+int NdbThread_SetScheduler(NDB_THAND_TYPE threadHandle, bool rt_prio,
+                           bool high_prio);
 
 /**
  * Lock Thread to CPU
  */
-int Ndb_LockCPU(NDB_TID_TYPE threadId, Uint32 cpu_id);
+int NdbThread_LockCPU(NDB_TID_TYPE threadId, Uint32 cpu_id);
 
 #ifdef	__cplusplus
 }
@@ -60,20 +60,20 @@
  * used to set real-time properties and lock threads to CPU's. In
  * the NDB API they are dummy subroutines.
- * add_thread_id is used before starting run method in thread.
- * remove_thread_id is called immediately after returning from
+ * ndb_thread_add_thread_id is used before starting run method in thread.
+ * ndb_thread_remove_thread_id is called immediately after returning from
  * run-method in thread.
@@ -60,20 +60,20 @@
  * run-method in thread.
- * fill_thread_object is called before calling add_thread_id to
- * prepare parameters.
+ * ndb_thread_fill_thread_object is called before calling
+ * ndb_thread_add_thread_id to prepare parameters.
  */
 void*
